Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1550)

Unified Diff: content/renderer/media/cdm/ppapi_decryptor.h

Issue 2568463003: media: Rename MediaKeys to ContentDecryptionModule (Closed)
Patch Set: comments addressed Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/renderer/media/cdm/ppapi_decryptor.h
diff --git a/content/renderer/media/cdm/ppapi_decryptor.h b/content/renderer/media/cdm/ppapi_decryptor.h
index 64b1507e7c38c790b90d0426b4e5eb905594ab59..d530f5d12f5ca9c622dc8cb7020d6e09b66128a1 100644
--- a/content/renderer/media/cdm/ppapi_decryptor.h
+++ b/content/renderer/media/cdm/ppapi_decryptor.h
@@ -16,8 +16,8 @@
#include "content/renderer/media/cdm/pepper_cdm_wrapper.h"
#include "media/base/cdm_context.h"
#include "media/base/cdm_factory.h"
+#include "media/base/content_decryption_module.h"
#include "media/base/decryptor.h"
-#include "media/base/media_keys.h"
#include "media/base/video_decoder_config.h"
class GURL;
@@ -29,10 +29,10 @@ class SingleThreadTaskRunner;
namespace content {
class ContentDecryptorDelegate;
// PpapiDecryptor implements media::MediaKeys and media::Decryptor and forwards
// all calls to the PluginInstance.
// This class should always be created & destroyed on the main renderer thread.
-class PpapiDecryptor : public media::MediaKeys,
+class PpapiDecryptor : public media::ContentDecryptionModule,
public media::CdmContext,
public media::Decryptor {
public:
@@ -48,7 +48,7 @@ class PpapiDecryptor : public media::MediaKeys,
const media::SessionExpirationUpdateCB& session_expiration_update_cb,
const media::CdmCreatedCB& cdm_created_cb);
- // media::MediaKeys implementation.
+ // media::ContentDecryptionModule implementation.
void SetServerCertificate(
const std::vector<uint8_t>& certificate,
std::unique_ptr<media::SimpleCdmPromise> promise) override;
@@ -113,7 +113,7 @@ class PpapiDecryptor : public media::MediaKeys,
// Callbacks for |plugin_cdm_delegate_| to fire session events.
void OnSessionMessage(const std::string& session_id,
- MediaKeys::MessageType message_type,
+ ContentDecryptionModule::MessageType message_type,
const std::vector<uint8_t>& message);
void OnSessionKeysChange(const std::string& session_id,
bool has_additional_usable_key,
@@ -29,10 +29,10 @@ class SingleThreadTaskRunner;
namespace content {
class ContentDecryptorDelegate;
-// PpapiDecryptor implements media::MediaKeys and media::Decryptor and forwards
-// all calls to the PluginInstance.
+// PpapiDecryptor implements media::ContentDecryptionModule and media::Decryptor
+// and forwards all calls to the PluginInstance.
// This class should always be created & destroyed on the main renderer thread.
« no previous file with comments | « content/renderer/media/android/webmediaplayer_android.cc ('k') | content/renderer/media/cdm/render_cdm_factory.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698